public inbox for linux-kernel@vger.kernel.org
 help / color / mirror / Atom feed
* [PATCH] x86/irq: fix move_irq_desc for node without ram
@ 2009-08-04 16:01 Yinghai Lu
  2009-08-08 15:21 ` [tip:irq/urgent] x86/irq: Fix move_irq_desc() for nodes " tip-bot for Yinghai Lu
  0 siblings, 1 reply; 2+ messages in thread
From: Yinghai Lu @ 2009-08-04 16:01 UTC (permalink / raw)
  To: Ingo Molnar, Thomas Gleixner, H. Peter Anvin; +Cc: linux-kernel@vger.kernel.org


don't move it if target node is -1

Signed-off-by: Yinghai Lu <yinghai@kernel.org>

---
 kernel/irq/numa_migrate.c |    4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

Index: linux-2.6/kernel/irq/numa_migrate.c
===================================================================
--- linux-2.6.orig/kernel/irq/numa_migrate.c
+++ linux-2.6/kernel/irq/numa_migrate.c
@@ -107,8 +107,8 @@ out_unlock:
 
 struct irq_desc *move_irq_desc(struct irq_desc *desc, int node)
 {
-	/* those all static, do move them */
-	if (desc->irq < NR_IRQS_LEGACY)
+	/* those static or target node is -1, do not move them */
+	if (desc->irq < NR_IRQS_LEGACY || node == -1)
 		return desc;
 
 	if (desc->node != node)

^ permalink raw reply	[flat|nested] 2+ messages in thread

end of thread, other threads:[~2009-08-08 15:22 UTC | newest]

Thread overview: 2+ messages (download: mbox.gz follow: Atom feed
-- links below jump to the message on this page --
2009-08-04 16:01 [PATCH] x86/irq: fix move_irq_desc for node without ram Yinghai Lu
2009-08-08 15:21 ` [tip:irq/urgent] x86/irq: Fix move_irq_desc() for nodes " tip-bot for Yinghai Lu

This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox